    /////////////////////////////////////////////////////////////////
   //             Arduino Weather Station #3             v1.01    //
  //       Get the latest version of the code here:              //
 //   http://educ8s.tv/arduino-weather-station-project-3        //
/////////////////////////////////////////////////////////////////


#include "DHT.h"
#include <SFE_BMP180.h>
#include <Wire.h>
#include <LCD5110_Graph.h>

#define ALTITUDE 216.0 // Altitude in Sparta, Greece

#define DHTPIN 22     // what pin we're connected to

#define DHTTYPE DHT22   

LCD5110 lcd(8,9,10,12,11);

SFE_BMP180 pressure;
extern unsigned char SmallFont[];
extern unsigned char TinyFont[];
int LDRpin = 13;
DHT dht(DHTPIN, DHTTYPE);

void setup(void) {

  lcd.InitLCD();
  lcd.setFont(TinyFont);
  lcd.print("Weather Station v0.3",CENTER,0);
  lcd.update();
  dht.begin();
  pressure.begin();
}

void loop() {
  
 float humidity, pressure, temperature;
 int lightIntensity = 0;
 
 humidity = dht.readHumidity();
 pressure = readPressure();
 temperature = dht.readTemperature();
 lightIntensity = readLightIntensity();

 delay(2000);

 lcd.clrScr(); 
 char tempF[6]; 
 char humF[6];
 char pressF[7];
 
dtostrf(temperature, 5, 1, tempF);
dtostrf(humidity, 5, 1, humF);
dtostrf(pressure, 5, 1, pressF);

//Turn On/Off Screen
if(lightIntensity<10)
{
  lcd.enableSleep();
}else
{
  lcd.disableSleep();
}

//Printing UI
lcd.setFont(TinyFont);
lcd.print("TEMP",LEFT+17,0);
lcd.print("HUM",LEFT+62,0);
lcd.print("PRESSURE",CENTER,30);

lcd.setFont(SmallFont);
 //Printing Temperature
lcd.print(tempF,LEFT,10);
lcd.print("~C",LEFT+30,10);

 //Printing Humidity
lcd.print(humF,LEFT+45,10);
lcd.print("%",RIGHT,10);

 //Printing Pressure
lcd.print(pressF,12,40);
lcd.print(" hPa",48,40);

lcd.update();
}

float readPressure()
{
  char status;
  double T,P,p0,a;

  status = pressure.startTemperature();
  if (status != 0)
  {
    delay(status);
    status = pressure.getTemperature(T);
    if (status != 0)
    { 
      status = pressure.startPressure(3);
      if (status != 0)
      {
        delay(status);
        status = pressure.getPressure(P,T);
        if (status != 0)
        {
          p0 = pressure.sealevel(P,ALTITUDE);       
          return p0;
        }
      }
    }
  }
}

int readLightIntensity()
{
   int intensity = analogRead(LDRpin);
   intensity = map(intensity, 1050, 20, 0, 100);
   return intensity;
}


